Welcome to Polvo
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

<img src="../assets/polvo.png" width=120/>

``` python
from IPython.display import Markdown, Image
```

``` python
logo = Image(filename="../assets/polvo.png")
```

``` python
Markdown(f"""
this is ![](../assets/polvo.png)
"""
)
```

this is ![](../assets/polvo.png)

<!-- ![myimg](../assets/polvo.png)&nbsp; test text -->

![myimg](../assets/polvo.png){: height=“75px” width=“300px”
style=“float:left; padding-right:10px” }

``` python
Markdown('![myimg](../assets/polvo.png){: height="75px" width="300px" style="float:left; padding-right:10px" }')
```

![myimg](../assets/polvo.png){: height=“75px” width=“300px”
style=“float:left; padding-right:10px” }

<!-- <img src="../assets/polvo.png" style="display=block; margin:auto" width=120/> -->

<img src="../assets/polvo.png" style="float: left;" width=120/>

<h2 style="padding: 00px">
Welcome to Polvo
</h2>
<p style="padding-right: 10px; padding-left: 20px">
Polvo is a collection of computer vision tools that I find helpful for
my personal workflow. Maybe some can be helpful for you too!
</p>

``` python
```

![](index_files/figure-gfm/cell-6-output-1.png)

## Install

`pip install polvo`

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
